// package_A/work/index.js
import {getOssAuth} from '../../../api/uploadOss.js'
Page({

    /**
     * 页面的初始数据
     */
    data: {
        form: {},
        ossForm: {},
        imagePreviewList: [], // 上传图片预览列表
        imageList: [], // 图片列表
        // 表单验证
        formRules: {
            location: {
                validator: function (value) {
                    return value;
                },
                warning: false
            },
            feedbackDesc: {
                validator: function (value) {
                  return value;
                },
                warning: false
            },
            feedbackName: {
                validator: function (value) {
                  return value;
                },
                warning: false
            },
            feedbackPhone: {
                validator: function (value) {
                  return value;
                },
                warning: false
            },
            imageList: {
                validator: function (value) {
                  return value.length!=0;
                },
                warning: false
            }
        }
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        let data = JSON.parse(options.data)
        let form = this.data.form
        form.streamName = data.name
        form.streamId = data.streamId
        this.setData({form})
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {
        
    },
    bindValue(e) {
        let name = e.currentTarget.dataset.name;
        let form = this.data.form;
        form[name] = e.detail.value;
        this.setData({
          form,
        })
        this.validate(name, e.detail.value)
      },
      validate(name) {
        let formRules = this.data.formRules;
        let validator = formRules[name].validator
        let result
        if(name === 'imageList') {
        result = validator ? !validator(this.data.imageList) : false
        } else {
        result = validator ? !validator(this.data.form[name]) : false;
        }
        formRules[name].warning = result
        this.setData({formRules})
        return result
      },
      validateForm() {
        return new Promise((resolve, reject) => {
          try {
            let formRules = this.data.formRules;
            let result = false;
            for (let key in formRules) {
              let temp = this.validate(key)
              if (temp) {
                result = temp
              }
            }
            resolve(!result)
          } catch (e) {
            reject(e)
          }
        })
      },
    /* 获取图片上传鉴权 */
    getOssAuthForm() {
        let that = this
        getOssAuth().then(res=> {
            let client = {
                region: 'oss-cn-shanghai',
                secure: true,
                accessKeyId: res.data.accessKeyId,
                accessKeySecret: res.data.accessKeySecret,
                securityToken: res.data.securityToken,
                bucket: 'ta-tech-image'
            }
            // 计算签名
            function computeSignature(accessKeySecret, canonicalString) {
                return crypto.enc.Base64.stringify(crypto.HmacSHA1(canonicalString, accessKeySecret));
            }
            const date = new Date();
            date.setHours(date.getHours() + 1);
            const policyText = {
                expiration: date.toISOString(), // 设置policy过期时间。
                conditions: [
                    // 限制上传大小。
                    ["content-length-range", 0, 1024 * 1024 * 1024],
                ],
            };
            // 获取签名
            const policy = Base64.encode(JSON.stringify(policyText)) // policy必须为base64的string。
            const signature = computeSignature(client.accessKeySecret, policy)
            let ossForm = that.data.ossForm
            ossForm = {
                OSSAccessKeyId: client.accessKeyId,
                signature,
                policy,
                SecurityToken: client.securityToken 
            }
            that.setData({ossForm})
        })
    
    },
    /* 上传图片 */
    uploadImage(){
        wx.chooseMedia({
          count: 5 - this.data.imageList.length, // 最多可以选择的图片张数，默认9
          mediaType: ['image'], // 图片
          sizeType: ['original'], // original 原图，compressed 压缩图，默认二者都有
          sourceType: ['album', 'camera'], // album 从相册选图，camera 使用相机，默认二者都有
          success: (res) => {
              // success
              let imagePreviewList = this.data.imagePreviewList.concat(res.tempFiles)
              let imageList = this.data.imageList.concat(res.tempFiles);
              this.setData({ imageList, imagePreviewList })
              this.validate('imageList')
          },
          fail: (e) => {
              console.log(e);
          }
        })
    },
    // 删除图片
    deleteImage(e) {
        let index = this.getCurrentData(e);
        let imageList = this.data.imageList
        imageList.splice(index, 1)
        let imagePreviewList = this.data.imagePreviewList
        imagePreviewList.splice(index, 1)
        this.setData({ imageList, imagePreviewList })
        this.validate('imageList')
    },
    getCurrentData(e) {
        return e.currentTarget.dataset.current;
    },
    /* 取消 */
    returnLastPage() {
        this.setData({
            form: {}
        })
        wx.navigateBack({
          delta: 1,
        })
    },

    /* 表单上传 */
    submit(){
        wx.navigateBack({
            delta: 1,
        })
    }
    
})